@@ -2,4 +2,9 @@
 The Viper library contains many useful tools to improve the capabilities of Python.
 """
 
+# Here are the necessary modules that need to be loaded with Viper:
+
+from .meta import procedural
+del procedural
+
 __all__ = ["abc", "building", "compress", "debugging", "meta", "better_threading", "exceptions", "format", "frozendict", "interactive", "pickle_utils", "warnings"]
\ No newline at end of file
